var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as path from "node:path";
import getLockfile from "../core/getLockfile.js";
import getNpmRegistry from "../core/getNpmRegistry.js";
import replaceLockfileRegistry from "../core/replaceLockfileRegistry.js";
const resolveLockfile = (value, dummyPrevious) => {
    const previous = dummyPrevious || [];
    const result = [...previous, path.resolve(process.cwd(), value)];
    return result;
};
export default function (program) {
    program
        .option("--lockfile <string...>", "lockfile, eg: ./package-lock.json ./yarn.lock", resolveLockfile)
        .option("--registry <string>", "registry, eg: https://registry.npmjs.org/")
        .action((opts) => __awaiter(this, void 0, void 0, function* () {
        let lockfile = opts.lockfile;
        if (!lockfile) {
            lockfile = getLockfile();
        }
        if (!lockfile.length) {
            console.error(`[replace-lockfile-registry] can not find lockfile from ${process.cwd()}.`);
            return;
        }
        let registry = opts.registry;
        if (!registry) {
            // 默认只用 npm 的 registry
            registry = getNpmRegistry();
        }
        replaceLockfileRegistry({
            lockfileList: lockfile,
            registry,
        });
    }));
}
